@@ -1,6 +1,5 @@
 #coding:utf8
 import sys,re, os, misaka as m
-from cgi import escape
 from farbox_markdown.zrey_utils import UnicodeWithAttrs, smart_unicode, smart_str
 from pygments.lexers.web import PhpLexer
 from pygments.lexers import get_lexer_by_name as _get_lexer_by_name, ClassNotFound
@@ -305,7 +304,7 @@ class FarBoxRenderer(m.HtmlRenderer):
                 lang = 'javascript'
 
         if not lang:
-            return '\n<pre><code>%s</code></pre>\n' %  escape(text)
+            return '\n<pre><code>%s</code></pre>\n' %  html_escape(text)
 
         # special syntax starts
         elif lang in ['mathjax', 'math']: # 处理数学公式 # <!--random_uuid-->
@@ -345,7 +344,7 @@ class FarBoxRenderer(m.HtmlRenderer):
                 return highlight(text, lexer, formatter)
             except: # ClassNotFound
                 # lang 不存在, 但保留lang到pre的class中
-                return '\n<pre class="lang_%s"><code>%s</code></pre>\n' %  (lang, escape(text))
+                return '\n<pre class="lang_%s"><code>%s</code></pre>\n' %  (lang, html_escape(text))
 
 
     def is_repeated_n_html(self, html):
